rusty_mos::kernel::syscall_impl

Function sys_bind_shared_pool

fn sys_bind_shared_pool(va: u32, id: u32, perm: u32) -> u32
SYSNO: 19, bind a existed memory pool.

The va shall be aligned to a PAGE_SIZE and the whole memory needed shall be in range [[UTEMP, UTOP]).

The id of the pool shall exist and one env cannot bind to the same pool altough the va is different.

Failure

This syscall will return a negated-KError returned by page_insert and bind.