rusty_mos::kernel::syscall_impl

Function sys_read_dev

fn sys_read_dev(va: u32, pa: u32, len: u32) -> u32
SYSNO: 17, read data from pa into va with the length of len.

The len can only be in 1, 2 or 4.

The pa is the same as that in sys_write_dev.

See Also: sys_write_dev

Failure

This syscall will return a negated-KError::Invalid if the va is out of the [[UTEMP, UTOP]) range, or the pa is invalid or the len is invalid.