rusty_mos::kernel::syscall_impl

Function sys_unlock

fn sys_unlock(id: u32) -> u32
SYSNO: 21, unlock a memory pool.

Only the env which locked pool can unlock it.

Failure

This syscall will return a negated-KError if the pool was not locked or locked by another env.

See Also: MemoryPool::unlock