fn sys_print_cons(s: *const u8, num: u32) -> u32Expand description
SYSNO: 1, show one num-lengthed string on the console.
It will call the print_charc function one by one to put each characters.
The string SHALL be under the UTOP wholy.
Failure
This syscall will return a negated-KError::Invalid if any of the string is above the UTOP.