fn sys_set_env_status(envid: u32, status: EnvStatus) -> u32Expand description
SYSNO: 10, set the run status of the specified env.
The status can only be EnvStatus::Runnable or EnvStatus::NotRunnable.
The env will be added to or removed from the ENV_SCHE_LIST to be or be
not scheduled.
The env shall be the current env or the child of the current env.
Failure
This syscall will return a negated-KError::Invalid if the status is
not allowed.
This syscall will return a negated-KError returned by envid2env.